@@ -208,17 +208,13 @@ class Dataset(Entity):
         dataset_urn: str,
         label: str,
         link: str,
-        platform: str = "bigquery",
-        env: str = "DEV",
     ) -> None:
         """Add link on dataset
 
         Args:
-            dataset_urn: The dataset urn.
+            dataset_urn: The dataset URN.
             label: The link label.
             link: Then URL link.
-            platform: The resource platform.
-            env: The resource env.
 
         Examples:
 
@@ -229,7 +225,7 @@ class Dataset(Entity):
                 "input": {
                     "linkUrl": link,
                     "label": label,
-                    "resourceUrn": self.create_resource_urn(dataset_urn, platform, env),
+                    "resourceUrn": dataset_urn,
                 }
             },
             "query": "mutation addLink($input: AddLinkInput!) {\n  addLink(input: $input)\n}\n",
